@@ -1,24 +1,36 @@
 #' Get Application Info
 #'
-#' Get Information about the Application, such as number of pages (given the money), when the application credits expire etc. The function prints the details, and returns a list with the details.
-#' @return A list with items including Name of the Application, No. of pages remaining (given the money), No. of fields remaining (given the money), and when the application credits expire. 
+#' Get Information about the Application, such as number of pages (given the money), 
+#' when the application credits expire etc. The function prints the details, and returns a 
+#' data.frame with the details.
+#' 
+#' @return A data.frame with the following fields: Name of the Application (name), 
+#' No. of pages remaining (pages), No. of fields remaining (fields), 
+#' when the application credits expire (expires) and type of application (type). 
+#' 
 #' @export
+#' 
 #' @references \url{http://ocrsdk.com/documentation/apireference/getApplicationInfo/}
 #' @references \url{http://ocrsdk.com/schema/appInfo-1.0.xsd}
+#' 
 #' @usage getAppInfo()
+#' 
 #' @examples \dontrun{
 #' getAppInfo()
 #' }
 
-getAppInfo <- function()
-{
+getAppInfo <- function() {
+
 	appinfo <- abbyy_GET("getApplicationInfo", query="")[[1]]
 
+	appinfo <- as.data.frame(appinfo)
+
 	cat("Name of Application: ", appinfo$name, "\n", sep = "")
   	cat("No. of Pages Remaining: ", appinfo$pages, "\n", sep = "")
   	cat("No. of Fields Remaining: ", appinfo$fields, "\n", sep = "")
   	cat("Application Credits Expire on: ", appinfo$expires, "\n", sep = "")
   	cat("Type: ", appinfo$type, "\n", sep = "")
+  	
   	return(invisible(appinfo))
 }
 
