@@ -1,13 +1,19 @@
 #' List Finished Tasks
 #'
-#' List all the finished tasks in the application. 
-#' From Abbyy FineReader: The tasks are ordered by the time of the end of processing. No more than 100 tasks can be returned at one method call. 
-#' The function prints number of finished tasks by default
+#' @description List all the finished tasks in the application. 
+#' 
+#' The tasks are ordered by the time of the end of processing. 
+#' No more than 100 tasks can be returned at one method call. 
+#' The function prints number of finished tasks by default.
+#' 
+#' @return A data frame with the following columns: id (task id), registrationTime, statusChangeTime, 
+#' status (Completed), filesCount (No. of files), credits, resultUrl (URL for the processed file)
 #' 
-#' @return A data frame with the following columns: id (task id), registrationTime, statusChangeTime, status (Completed), filesCount (No. of files), credits, resultUrl (URL for the processed file)
 #' @export
 #' @references \url{http://ocrsdk.com/documentation/apireference/listFinishedTasks/}
+#' 
 #' @usage listFinishedTasks()
+#' 
 #' @examples \dontrun{
 #' listFinishedTasks()
 #' }
@@ -27,7 +33,8 @@ listFinishedTasks <- function() {
 	}
 
 	resdf <- as.data.frame(do.call(rbind, tasklist)) # collapse to a data.frame
-
+	row.names(resdf) <- 1:nrow(resdf)	# row.names for the df
+	
 	# Print some important things
 	cat("No. of Finished Tasks: ", nrow(resdf), "\n")
 
