@@ -1,15 +1,20 @@
 #' Process Bar Code Field
 #'
-#' This function gets Information about a particular application
+#' Process the bar code field in an image.
+#' 
 #' @param file_path path of the document
 #' @param barcodeType optional, default: "autodetect"
 #' @param region coordinates of region from top left, 4 values: top left bottom right; optional; default: "-1,-1,-1,-1" (entire image) 
 #' @param containsBinaryData   optional, default: "false"
 #' @param pdfPassword  optional, default: ""
 #' @param description  optional, default: ""
+#' 
 #' @return Data frame with details of the task associated with the submitted Image
+#' 
 #' @export
+#' 
 #' @references \url{http://ocrsdk.com/documentation/apireference/processBarcodeField/}
+#' 
 #' @examples \dontrun{
 #' processBarcodeField(file_path="file_path")
 #' }
@@ -20,8 +25,7 @@ processBarcodeField <- function(file_path="", barcodeType="autodetect", region="
 
 	querylist = list(barcodeType=barcodeType, region=region, containsBinaryData=containsBinaryData, pdfPassword=pdfPassword, description=description)
 	
-	body=upload_file(file_path)
-	process_details <- abbyy_POST("processBarcodeField", query=querylist, body=body)
+	process_details <- abbyy_POST("processBarcodeField", query=querylist, body=upload_file(file_path))
 	
 	resdf <- as.data.frame(do.call(rbind, process_details)) # collapse to a data.frame
 
