@@ -36,12 +36,10 @@ processTextField <- function(file_path="", region="-1,-1,-1,-1", language="Engli
 		             writingStyle = writingStyle, description = description, pdfPassword = pdfPassword)
 
 	body  <- upload_file(file_path)
-	processdetails <- abbyy_POST("processTextField", query=querylist, body=body)
+	process_details <- abbyy_POST("processTextField", query=querylist, body=body)
 			
-	resdf <- do.call(rbind.data.frame, processdetails) # collapse to a data.frame
-	names(resdf) <- names(processdetails[[1]])[1:length(resdf)] # names for the df, adjust for <7
-	row.names(resdf) <- 1:nrow(resdf)	# row.names for the df
-
+	resdf <- as.data.frame(do.call(rbind, process_details)) # collapse to a data.frame
+	
 	# Print some important things
 	cat("Status of the task: ", resdf$status, "\n")
 	cat("Task ID: ", 			resdf$id, "\n")
