@@ -1,12 +1,15 @@
 context("Submit, Process Image")
 
-token <- c(Sys.getenv('AbbyyAppId'), Sys.getenv('AbbyyAppPassword'))
-
 image <- system.file("extdata/t1.png", package = "abbyyR")
 
 test_that("submitImage, processImage happens successfully", {
   skip_on_cran()
-  setapp(token)
+  
+  token_file <- file("abbyy_key", "r")
+  token <- suppressWarnings(readLines(token_file))
+  close(token_file)
+  setapp(unlist(strsplit(token, ",")))
+
   sub_img <- submitImage(file_path=image)
   proc_img <- processImage(file_path=image)
 
